==> rirods_0.1.1.tar.gz: rirods/tests/testthat/print-3/list-426d3d.R <==
structure(list(method = "GET", url = "/list?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Ffred.rds&stat=0&permissions=0&metadata=0&offset=0&limit=100", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Thu, 29 Jun 2023 06:41:02 GMT", `Content-Length` = "837", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x7b, 0x22, 0x5f, 0x65, 0x6d, 0x62, 0x65, 
    0x64, 0x64, 0x65, 0x64, 0x22, 0x3a, 0x5b, 0x7b, 0x22, 0x6c, 
    0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x5f, 0x70, 0x61, 0x74, 
    0x68, 0x22, 0x3a, 0x22, 0x2f, 0x74, 0x65, 0x6d, 0x70, 0x5a, 
    0x6f, 0x6e, 0x65, 0x2f, 0x68, 0x6f, 0x6d, 0x65, 0x2f, 0x72, 
    0x6f, 0x64, 0x73, 0x2f, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 
    0x61, 0x74, 0x2f, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 0x64, 
    0x73, 0x22, 0x2c, 0x22, 0x74, 0x79, 0x70, 0x65, 0x22, 0x3a, 
    0x22, 0x64, 0x61, 0x74, 0x61, 0x5f, 0x6f, 0x62, 0x6a, 0x65, 
    0x63, 0x74, 0x22, 0x7d, 0x5d, 0x2c, 0x22, 0x5f, 0x6c, 0x69, 
    0x6e, 0x6b, 0x73, 0x22, 0x3a, 0x7b, 0x22, 0x66, 0x69, 0x72, 
    0x73, 0x74, 0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 
    0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 
    0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 
    0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 
    0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 
    0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 
    0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 
    0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 
    0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 
    0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 
    0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 
    0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 
    0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x30, 0x26, 
    0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 
    0x2c, 0x22, 0x6c, 0x61, 0x73, 0x74, 0x22, 0x3a, 0x22, 0x2f, 
    0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 
    0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 
    0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 
    0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 
    0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 
    0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 
    0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 
    0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 
    0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 
    0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 
    0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 
    0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 
    0x74, 0x3d, 0x55, 0x4e, 0x53, 0x55, 0x50, 0x50, 0x4f, 0x52, 
    0x54, 0x45, 0x44, 0x26, 0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 
    0x31, 0x30, 0x30, 0x22, 0x2c, 0x22, 0x6e, 0x65, 0x78, 0x74, 
    0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 
    0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 
    0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 
    0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 
    0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 
    0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 
    0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 
    0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 
    0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 
    0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 
    0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 
    0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 
    0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x26, 
    0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 
    0x2c, 0x22, 0x70, 0x72, 0x65, 0x76, 0x22, 0x3a, 0x22, 0x2f, 
    0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 
    0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 
    0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 
    0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 
    0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 
    0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 
    0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 
    0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 
    0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 
    0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 
    0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 
    0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 
    0x74, 0x3d, 0x30, 0x26, 0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 
    0x31, 0x30, 0x30, 0x22, 0x2c, 0x22, 0x73, 0x65, 0x6c, 0x66, 
    0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 
    0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 
    0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 
    0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 
    0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 
    0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 
    0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 
    0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 
    0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 
    0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 
    0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 
    0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 
    0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x30, 0x26, 0x6c, 0x69, 
    0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 0x7d, 0x7d
    ))), class = "httr2_response")

==> rirods_0.1.2.tar.gz: rirods/tests/testthat/print-3/list-426d3d.R <==
structure(list(method = "GET", url = "/list?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Ffred.rds&stat=0&permissions=0&metadata=0&offset=0&limit=100", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:42 GMT", `Content-Length` = "837", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x7b, 0x22, 0x5f, 0x65, 0x6d, 0x62, 0x65, 
    0x64, 0x64, 0x65, 0x64, 0x22, 0x3a, 0x5b, 0x7b, 0x22, 0x6c, 
    0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x5f, 0x70, 0x61, 0x74, 
    0x68, 0x22, 0x3a, 0x22, 0x2f, 0x74, 0x65, 0x6d, 0x70, 0x5a, 
    0x6f, 0x6e, 0x65, 0x2f, 0x68, 0x6f, 0x6d, 0x65, 0x2f, 0x72, 
    0x6f, 0x64, 0x73, 0x2f, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 
    0x61, 0x74, 0x2f, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 0x64, 
    0x73, 0x22, 0x2c, 0x22, 0x74, 0x79, 0x70, 0x65, 0x22, 0x3a, 
    0x22, 0x64, 0x61, 0x74, 0x61, 0x5f, 0x6f, 0x62, 0x6a, 0x65, 
    0x63, 0x74, 0x22, 0x7d, 0x5d, 0x2c, 0x22, 0x5f, 0x6c, 0x69, 
    0x6e, 0x6b, 0x73, 0x22, 0x3a, 0x7b, 0x22, 0x66, 0x69, 0x72, 
    0x73, 0x74, 0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 
    0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 
    0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 
    0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 
    0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 
    0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 
    0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 
    0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 
    0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 
    0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 
    0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 
    0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 
    0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x30, 0x26, 
    0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 
    0x2c, 0x22, 0x6c, 0x61, 0x73, 0x74, 0x22, 0x3a, 0x22, 0x2f, 
    0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 
    0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 
    0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 
    0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 
    0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 
    0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 
    0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 
    0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 
    0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 
    0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 
    0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 
    0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 
    0x74, 0x3d, 0x55, 0x4e, 0x53, 0x55, 0x50, 0x50, 0x4f, 0x52, 
    0x54, 0x45, 0x44, 0x26, 0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 
    0x31, 0x30, 0x30, 0x22, 0x2c, 0x22, 0x6e, 0x65, 0x78, 0x74, 
    0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 
    0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 
    0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 
    0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 
    0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 
    0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 
    0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 
    0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 
    0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 
    0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 
    0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 
    0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 
    0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x26, 
    0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 
    0x2c, 0x22, 0x70, 0x72, 0x65, 0x76, 0x22, 0x3a, 0x22, 0x2f, 
    0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 0x72, 0x65, 0x73, 0x74, 
    0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 0x2f, 0x6c, 0x69, 0x73, 
    0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 0x63, 0x61, 0x6c, 0x2d, 
    0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 0x32, 0x46, 0x74, 0x65, 
    0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 0x25, 0x32, 0x46, 0x68, 
    0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 0x72, 0x6f, 0x64, 0x73, 
    0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 0x74, 0x74, 0x68, 0x61, 
    0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 0x65, 0x64, 0x2e, 0x72, 
    0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 0x74, 0x3d, 0x30, 0x26, 
    0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 0x73, 0x69, 0x6f, 0x6e, 
    0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 0x74, 0x61, 0x64, 0x61, 
    0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 0x66, 0x66, 0x73, 0x65, 
    0x74, 0x3d, 0x30, 0x26, 0x6c, 0x69, 0x6d, 0x69, 0x74, 0x3d, 
    0x31, 0x30, 0x30, 0x22, 0x2c, 0x22, 0x73, 0x65, 0x6c, 0x66, 
    0x22, 0x3a, 0x22, 0x2f, 0x69, 0x72, 0x6f, 0x64, 0x73, 0x2d, 
    0x72, 0x65, 0x73, 0x74, 0x2f, 0x30, 0x2e, 0x39, 0x2e, 0x33, 
    0x2f, 0x6c, 0x69, 0x73, 0x74, 0x3f, 0x6c, 0x6f, 0x67, 0x69, 
    0x63, 0x61, 0x6c, 0x2d, 0x70, 0x61, 0x74, 0x68, 0x3d, 0x25, 
    0x32, 0x46, 0x74, 0x65, 0x6d, 0x70, 0x5a, 0x6f, 0x6e, 0x65, 
    0x25, 0x32, 0x46, 0x68, 0x6f, 0x6d, 0x65, 0x25, 0x32, 0x46, 
    0x72, 0x6f, 0x64, 0x73, 0x25, 0x32, 0x46, 0x74, 0x65, 0x73, 
    0x74, 0x74, 0x68, 0x61, 0x74, 0x25, 0x32, 0x46, 0x66, 0x72, 
    0x65, 0x64, 0x2e, 0x72, 0x64, 0x73, 0x26, 0x73, 0x74, 0x61, 
    0x74, 0x3d, 0x30, 0x26, 0x70, 0x65, 0x72, 0x6d, 0x69, 0x73, 
    0x73, 0x69, 0x6f, 0x6e, 0x73, 0x3d, 0x30, 0x26, 0x6d, 0x65, 
    0x74, 0x61, 0x64, 0x61, 0x74, 0x61, 0x3d, 0x30, 0x26, 0x6f, 
    0x66, 0x66, 0x73, 0x65, 0x74, 0x3d, 0x30, 0x26, 0x6c, 0x69, 
    0x6d, 0x69, 0x74, 0x3d, 0x31, 0x30, 0x30, 0x22, 0x7d, 0x7d
    ))), class = "httr2_response")
